@@ -16,7 +16,6 @@
 #'
 #'
 #' @examples
-#' \dontrun{
 #' crimesub <- stpm(valenciacrimes$df[101:200, ],
 #'            names = colnames(valenciacrimes$df)[-c(1:3)],
 #' L = valencianet)
@@ -26,13 +25,11 @@
 #'                   
 #' mod1
 #' 
-#'}
 #'
 #'
 #'
 print.sepstlppm <- function(x, ...){
-  if (!inherits(x, c("sepstlppm"))) stop("X should be from class sepstlppm")
-  
+
     cat("Fitted separable spatio-temporal Poisson process model \n")
     cat("on a linear network \n")
 }
