@@ -13,7 +13,6 @@
 #'
 #' @examples
 #'
-#' \dontrun{
 #' set.seed(2)
 #' df <- data.frame(x = runif(100, 0, 0.8), y = runif(100, 0, 0.8), t = runif(100), m = rpois(100, 15))
 #'
@@ -21,13 +20,11 @@
 #'
 #' stlpm1
 #' 
-#' }
 #'
 #'
 print.stlpm <- function (x, ...) 
 {
-  if (!inherits(x, c("stlpm"))) stop("X should be from class stlpm")
-  
+
   cat("Spatio-temporal marked point pattern \n")
   {
     cat(paste0(nrow(x$df), " ", "points"), "\n")
