@@ -15,7 +15,6 @@
 #'
 #'
 #' @examples
-#' \dontrun{
 #'
 #' crimesub <- stpm(valenciacrimes$df[101:200, ],
 #'            names = colnames(valenciacrimes$df)[-c(1:3)])
@@ -24,13 +23,11 @@
 #'                   timeformula = ~ day)
 #'                   
 #'summary(mod1)
-#'}
 #'
 #'
 #'
 summary.sepstppm <- function(object, ...){
-  if(!inherits(object, "sepstppm")) stop("class(object) must be sepstppm")
-  
+
   cat("Fitted separable spatio-temporal Poisson process model \n")
   cat("with spatial estimates: \n \n")
   print(summary(object$spacemod)$coefs.SE.CI)
